Index: Source/web/tests/WebFrameTest.cpp |
diff --git a/Source/web/tests/WebFrameTest.cpp b/Source/web/tests/WebFrameTest.cpp |
index e281bd954a983560bcb1e80e1e437be5d4da8318..0cb7cb1e13e18ba7ca917f3fcd47d77c2ba58c8d 100644 |
--- a/Source/web/tests/WebFrameTest.cpp |
+++ b/Source/web/tests/WebFrameTest.cpp |
@@ -42,7 +42,7 @@ |
#include "core/css/resolver/ViewportStyleResolver.h" |
#include "core/dom/DocumentMarkerController.h" |
#include "core/dom/Fullscreen.h" |
-#include "core/dom/NodeLayoutStyle.h" |
+#include "core/dom/NodeComputedStyle.h" |
#include "core/dom/Range.h" |
#include "core/editing/Editor.h" |
#include "core/editing/FrameSelection.h" |
@@ -474,7 +474,7 @@ TEST_F(WebFrameCSSCallbackTest, AuthorStyleSheet) |
EXPECT_THAT(matchedSelectors(), ElementsAre()); |
} |
-TEST_F(WebFrameCSSCallbackTest, SharedLayoutStyle) |
+TEST_F(WebFrameCSSCallbackTest, SharedComputedStyle) |
{ |
// Check that adding an element calls back when it matches an existing rule. |
std::vector<WebString> selectors; |
@@ -488,9 +488,9 @@ TEST_F(WebFrameCSSCallbackTest, SharedLayoutStyle) |
EXPECT_EQ(1, updateCount()); |
EXPECT_THAT(matchedSelectors(), ElementsAre("span")); |
// Adding a second element that shares a LayoutStyle shouldn't call back. |
// We use <span>s to avoid default style rules that can set |
- // LayoutStyle::unique(). |
+ // ComputedStyle::unique(). |
executeScript( |
"i2 = document.createElement('span');" |
"i2.id = 'second_span';" |
@@ -488,9 +488,9 @@ TEST_F(WebFrameCSSCallbackTest, SharedLayoutStyle) |
EXPECT_EQ(1, updateCount()); |
EXPECT_THAT(matchedSelectors(), ElementsAre("span")); |
- // Adding a second element that shares a LayoutStyle shouldn't call back. |
+ // Adding a second element that shares a ComputedStyle shouldn't call back. |
// We use <span>s to avoid default style rules that can set |